@@ -27,7 +27,10 @@ __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_Display_Text.git"
 
 
 try:
-    from typing import Tuple
+    from typing import Union, Optional, Tuple
+    from fontio import BuiltinFont
+    from adafruit_bitmap_font.bdf import BDF
+    from adafruit_bitmap_font.pcf import PCF
 except ImportError:
     pass
 
@@ -44,8 +47,9 @@ class Label(LabelBase):
     glyph (if its one line), or the (number of lines * linespacing + M)/2. That is,
     it will try to have it be center-left as close as possible.
 
-    :param Font font: A font class that has ``get_bounding_box`` and ``get_glyph``.
+    :param font: A font class that has ``get_bounding_box`` and ``get_glyph``.
       Must include a capital M for measuring character size.
+    :type font: ~BuiltinFont, ~BDF, or ~PCF
     :param str text: Text to display
     :param int color: Color of all text in RGB hex
     :param int background_color: Color of the background, use `None` for transparent
@@ -79,7 +83,7 @@ class Label(LabelBase):
      configurations possibles ``LTR``-Left-To-Right ``RTL``-Right-To-Left
      ``TTB``-Top-To-Bottom ``UPR``-Upwards ``DWR``-Downwards. It defaults to ``LTR``"""
 
-    def __init__(self, font, **kwargs) -> None:
+    def __init__(self, font: Union[BuiltinFont, BDF, PCF], **kwargs) -> None:
         self._background_palette = Palette(1)
         self._added_background_tilegrid = False
 
@@ -166,9 +170,11 @@ class Label(LabelBase):
 
         return tile_grid
 
-    def _set_background_color(self, new_color: int) -> None:
+    def _set_background_color(self, new_color: Optional[int]) -> None:
         """Private class function that allows updating the font box background color
-        :param int new_color: color as an RGB hex number."""
+
+        :param int new_color: Color as an RGB hex number, setting to None makes it transparent
+        """
 
         if new_color is None:
             self._background_palette.make_transparent(0)
@@ -397,7 +403,7 @@ class Label(LabelBase):
         self._update_text(str(self._replace_tabs(new_text)))
         self.anchored_position = current_anchored_position
 
-    def _set_font(self, new_font) -> None:
+    def _set_font(self, new_font: Union[BuiltinFont, BDF, PCF]) -> None:
         old_text = self._text
         current_anchored_position = self.anchored_position
         self._text = ""
